Module: RubyCurses

Extended by:
RubyCurses
Included in:
RubyCurses
Defined in:
lib/canis/core/util/basestack.rb,
lib/canis/core/widgets/extras/stackflow.rb

Overview

Common stack flow functionality

  • Name: basestack.rb

  • Description: Classes that allow user to stack and flow components This is currently used only by experimental. core does not use this for stack and flow. it uses wsshortcuts which does not maintain objects. This maintains objects.

  • Date: 30.10.11 - 12:57

  • Last update: 2014-05-02 20:15

Defined Under Namespace

Modules: ModStack Classes: StackFlow